@@ -15,17 +15,14 @@ SCV implementation of DatasetMetadataAbstract
 
 """
 
+
 class DatasetMetadataSCV(DatasetsMetaDataAbstractTable):
-     
-     def __init__(self,destenation,source=None) -> None:
-         super().__init__(destenation,source)
-         if (self.source is not None):
+
+    def __init__(self, destenation, source=None) -> None:
+        super().__init__(destenation, source)
+        if (self.source is not None):
             self.data = pd.read_csv(self.source)
-     
-     def create(self):
-          self.data.to_csv(self.destenation)
-     
-     
-     
-     
-     
+        else:
+             self.data = pd.DataFrame([])
+    def create(self):
+        self.data.to_csv(self.destenation)
